@@ -1,11 +1,12 @@
 ## File Name: Scale.R
-## File Version: 9.02
+## File Version: 9.03
 
 
 
 #####################################################
 # S3 method Scale
-Scale <- function (object, ...) {
-  UseMethod("Scale")
+Scale <- function (object, ...)
+{
+    UseMethod("Scale")
 }
 #####################################################
