@@ -1,5 +1,5 @@
 ## File Name: tam.mml.3pl.R
-## File Version: 9.853
+## File Version: 9.8541
 tam.mml.3pl <- function( resp, Y=NULL, group=NULL,
             formulaY=NULL, dataY=NULL,
             ndim=1, pid=NULL,
@@ -721,7 +721,7 @@ tam.mml.3pl <- function( resp, Y=NULL, group=NULL,
                 gammaslope=gammaslope, gammaslope.fixed=gammaslope.fixed,
                 gammaslope.constr.V=gammaslope.constr.V, gammaslope.constr.Npars=gammaslope.constr.Npars,
                 gammaslope.center.index=gammaslope.center.index, gammaslope.prior=gammaslope.prior,
-                numdiff.parm=5*1E-4)
+                numdiff.parm=5*1E-4, pweights=pweights, resp.ind=resp.ind)
 
     #***
     # calculate counts
