@@ -1,5 +1,5 @@
 ## File Name: tam.mml.mfr.R
-## File Version: 9.912
+## File Version: 9.9134
 
 tam.mml.mfr <- function( resp, Y=NULL, group=NULL,  irtmodel="1PL",
             formulaY=NULL, dataY=NULL,
@@ -472,10 +472,11 @@ tam.mml.mfr <- function( resp, Y=NULL, group=NULL,  irtmodel="1PL",
                 beta=beta, beta.fixed=beta.fixed, ndim=ndim,
                 variance.fixed=variance.fixed, G=G, irtmodel=irtmodel, B_orig=NULL,
                 B.fixed=B.fixed, E=E, est.variance=TRUE, resp=resp,
-                est.slopegroups=NULL, variance.Npars=NULL, group=group, penalty_xsi=penalty_xsi )
+                est.slopegroups=NULL, variance.Npars=NULL, group=group,
+                penalty_xsi=penalty_xsi, pweights=pweights, resp.ind=resp.ind )
 
-    #***
-    # calculate counts
+
+    #*** calculate counts
     res <- tam_calc_counts( resp=gresp.noStep, theta=theta, resp.ind=gresp.noStep.ind,
                 group=group, maxK=maxK, pweights=pweights, hwt=hwt )
     n.ik <- res$n.ik
@@ -495,11 +496,7 @@ tam.mml.mfr <- function( resp, Y=NULL, group=NULL,  irtmodel="1PL",
 
     #******
     s2 <- Sys.time()
-
-    item <- data.frame( "xsi.index"=1:np,
-                        "xsi.label"=dimnames(A)[[3]],
-                        "est"=xsi )
-
+    item <- data.frame( "xsi.index"=1:np, "xsi.label"=dimnames(A)[[3]], "est"=xsi )
     if (progress){
         cat(disp)
         cat("Item Parameters\n")
