@@ -1,5 +1,5 @@
 ## File Name: tam_dtnorm.R
-## File Version: 0.09
+## File Version: 0.11
 
 #--- This is a copy of msm::dtnorm
 tam_dtnorm <- function(x, mean=0, sd=1, lower=-Inf, upper=Inf, log=FALSE)
@@ -9,7 +9,7 @@ tam_dtnorm <- function(x, mean=0, sd=1, lower=-Inf, upper=Inf, log=FALSE)
     ret[upper < lower] <- NaN
     ind <- x >=lower & x <=upper
     if (any(ind)) {
-        denom <- stats::pnorm(x=upper, mean=mean, sd=sd) - stats::pnorm(x=lower, mean=mean, sd=sd)
+        denom <- stats::pnorm(q=upper, mean=mean, sd=sd) - stats::pnorm(q=lower, mean=mean, sd=sd)
         xtmp <- stats::dnorm(x=x, mean=mean, sd=sd, log=log)
         if (log)
             xtmp <- xtmp - log(denom)
